@@ -57,8 +57,9 @@ def generate_standard_messages_from_string(input_file_contents):
     raw_messages = generate_raw_messages(input_file_contents)
     standard_messages = []
     for message in raw_messages:
-        standard_messages.append(
-            generate_rtdh_standard_message_from_raw_single(message))
+        standard_message = generate_rtdh_standard_message_from_raw_single(message)
+        if standard_message:
+            standard_messages.append(standard_message)
     return standard_messages
 
 
@@ -86,7 +87,8 @@ def expand_event_directions(message):
             for laneImpact2 in new_message['properties']['laneImpacts']:
                 if direction_string == laneImpact2['direction']:
                     new_message['properties']['laneImpacts'] = [laneImpact2]
-                    new_message['properties']['recorded_direction'] = message['properties']['direction']
+                    new_message['properties']['recorded_direction'] = map_direction_string(
+                        message['properties']['direction'])
                     new_message['properties']['laneImpacts'][0]['direction'] = direction
                     break
             new_message['properties'][
@@ -271,6 +273,13 @@ def get_lane_impacts(lane_impacts, direction):
             return get_lanes_list(impact['laneClosures'], impact['laneCount'], impact['closedLaneTypes'])
 
 
+def any_lanes_closed(lanes):
+    for i in lanes:
+        if i['status'] != 'open':
+            return True
+    return False
+
+
 def create_rtdh_standard_msg(pd):
     coordinates = get_linestring(pd.get('geometry', default={'type': None}))
 
@@ -278,9 +287,7 @@ def create_rtdh_standard_msg(pd):
 
     beginning_milepost = pd.get("properties/startMarker", default="")
     ending_milepost = pd.get("properties/endMarker", default="")
-    print(direction, map_direction_string(
-        pd.get("properties/recorded_direction")))
-    recorded_direction = map_direction_string(pd.get("properties/recorded_direction"))
+    recorded_direction = pd.get("properties/recorded_direction")
     if direction == REVERSED_DIRECTION_MAP.get(recorded_direction):
         coordinates.reverse()
         beginning_milepost = pd.get("properties/endMarker", default="")
@@ -301,6 +308,11 @@ def create_rtdh_standard_msg(pd):
     if pd.get('properties/isOversizedLoadsProhibited'):
         restrictions.append({'type': 'permitted-oversize-loads-prohibited'})
 
+    lane_impacts = get_lane_impacts(pd.get("properties/laneImpacts"), pd.get("properties/direction"))
+    if not any_lanes_closed(lane_impacts):
+        return {}
+
+
     return {
         "rtdh_timestamp": time.time(),
         "rtdh_message_id": str(uuid.uuid4()),
@@ -324,7 +336,7 @@ def create_rtdh_standard_msg(pd):
                 "direction": direction,
             },
             "additional_info": {
-                "lanes": get_lane_impacts(pd.get("properties/laneImpacts"), pd.get("properties/direction")),
+                "lanes": lane_impacts,
                 "restrictions": restrictions,
                 "beginning_milepost": beginning_milepost,
                 "ending_milepost": ending_milepost,
